==> aspose_words_cloud-23.2.0.tar.gz: lib/src/models/custom_xml_parts_collection.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="custom_xml_parts_collection.dart">
 *   Copyright (c) 2023 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// The collection of CustomXmlPart.
class CustomXmlPartsCollection extends LinkElement {
  /// Gets or sets the collection of CustomXmlPart.
  List<CustomXmlPart> _customXmlPartsList;

  List<CustomXmlPart> get customXmlPartsList => _customXmlPartsList;
  set customXmlPartsList(List<CustomXmlPart> val) => _customXmlPartsList = val;

  @override
  void deserialize(Map<String, dynamic> json) {
    if (json == null) {
      throw ApiException(
          400, 'Failed to deserialize CustomXmlPartsCollection data model.');
    }

    super.deserialize(json);
    if (json.containsKey('Link')) {
      link = WordsApiLink();
      link.deserialize(json['Link'] as Map<String, dynamic>);
    } else {
      link = null;
    }

    if (json.containsKey('CustomXmlPartsList')) {
      // Array processing
      customXmlPartsList = <CustomXmlPart>[];
      for (final _element in json['CustomXmlPartsList']) {
        var _elementValue = CustomXmlPart();
        _elementValue.deserialize(_element as Map<String, dynamic>);
        customXmlPartsList.add(_elementValue);
      }
    } else {
      customXmlPartsList = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = <String, dynamic>{};
    _result.addAll(super.serialize());
    if (customXmlPartsList != null) {
      _result['CustomXmlPartsList'] =
          customXmlPartsList.map((_element) => _element.serialize()).toList();
    }
    return _result;
  }

  @override
  void getFilesContent(List<FileReference> resultFilesContent) {}
}

==> aspose_words_cloud-23.5.0.tar.gz: lib/src/models/custom_xml_parts_collection.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="custom_xml_parts_collection.dart">
 *   Copyright (c) 2023 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// The collection of CustomXmlPart.
class CustomXmlPartsCollection extends LinkElement {
  /// Gets or sets the collection of CustomXmlPart.
  List<CustomXmlPart?>? _customXmlPartsList;

  List<CustomXmlPart?>? get customXmlPartsList => _customXmlPartsList;
  set customXmlPartsList(List<CustomXmlPart?>? val) =>
      _customXmlPartsList = val;

  @override
  void deserialize(Map<String, dynamic>? json) {
    if (json == null) {
      throw ApiException(
          400, 'Failed to deserialize CustomXmlPartsCollection data model.');
    }

    super.deserialize(json);
    if (json.containsKey('Link')) {
      link = WordsApiLink();
      link!.deserialize(json['Link'] as Map<String, dynamic>);
    } else {
      link = null;
    }

    if (json.containsKey('CustomXmlPartsList')) {
      // Array processing
      customXmlPartsList = <CustomXmlPart>[];
      for (final _element in json['CustomXmlPartsList']) {
        var _elementValue = CustomXmlPart();
        _elementValue.deserialize(_element as Map<String, dynamic>);
        customXmlPartsList!.add(_elementValue);
      }
    } else {
      customXmlPartsList = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = <String, dynamic>{};
    _result.addAll(super.serialize());
    if (customXmlPartsList != null) {
      _result['CustomXmlPartsList'] =
          customXmlPartsList!.map((_element) => _element?.serialize()).toList();
    }
    return _result;
  }

  @override
  void getFilesContent(List<FileReference> resultFilesContent) {}
}
